////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  blur_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "blur_1_0_0.h"
#include "parametersetmanager.h"

BLUR_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_pass_reserve_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)pass_trigger, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "pass_data") == 0)
    {
        __result = pass_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_pass_reserve_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            pass_trigger = (ispglobalelements::trigger_pass)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "pass_data") == 0)
    {
        __result = pass_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_pass_reserve_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // pass_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pass_trigger", ParameterParserDataType::Enum, (double)(UINT32)pass_trigger, 0));
    }
    else if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)pass_trigger, 0));
    }

    // pass_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pass_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pass_data") == 0)
    {
        __result = pass_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_pass_reserve_dataType::pass_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "map_lut_en") == 0)
    {
        ParameterUtils::DoubleToString((double)map_lut_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "jbu_en") == 0)
    {
        ParameterUtils::DoubleToString((double)jbu_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_1_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_2_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_3_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_4_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_5_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_1_chroma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_2_chroma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_3_chroma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_4_chroma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)dc2_filter_coef_5_chroma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_interval_shift") == 0)
    {
        ParameterUtils::DoubleToString((double)renoise_blur_2_noise_factor_curve_interval_shift, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "use_map_from_lower_pass") == 0)
    {
        ParameterUtils::DoubleToString((double)use_map_from_lower_pass, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool mod_blur10_pass_reserve_dataType::pass_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "map_lut_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            map_lut_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "jbu_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            jbu_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_1_luma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_2_luma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_3_luma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_4_luma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_5_luma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_1_chroma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_2_chroma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_3_chroma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_4_chroma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dc2_filter_coef_5_chroma = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_interval_shift") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            renoise_blur_2_noise_factor_curve_interval_shift = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "use_map_from_lower_pass") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            use_map_from_lower_pass = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool mod_blur10_pass_reserve_dataType::pass_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // map_lut_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("map_lut_en", ParameterParserDataType::UInt32, (double)map_lut_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "map_lut_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)map_lut_en, 0));
    }

    // jbu_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("jbu_en", ParameterParserDataType::UInt32, (double)jbu_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "jbu_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)jbu_en, 0));
    }

    // dc2_filter_coef_1_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_1_luma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_1_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_1_luma, 0));
    }

    // dc2_filter_coef_2_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_2_luma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_2_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_2_luma, 0));
    }

    // dc2_filter_coef_3_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_3_luma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_3_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_3_luma, 0));
    }

    // dc2_filter_coef_4_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_4_luma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_4_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_4_luma, 0));
    }

    // dc2_filter_coef_5_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_5_luma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_5_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_5_luma, 0));
    }

    // dc2_filter_coef_1_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_1_chroma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_1_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_1_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_1_chroma, 0));
    }

    // dc2_filter_coef_2_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_2_chroma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_2_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_2_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_2_chroma, 0));
    }

    // dc2_filter_coef_3_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_3_chroma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_3_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_3_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_3_chroma, 0));
    }

    // dc2_filter_coef_4_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_4_chroma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_4_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_4_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_4_chroma, 0));
    }

    // dc2_filter_coef_5_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dc2_filter_coef_5_chroma", ParameterParserDataType::UInt32, (double)dc2_filter_coef_5_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dc2_filter_coef_5_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dc2_filter_coef_5_chroma, 0));
    }

    // renoise_blur_2_noise_factor_curve_interval_shift
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("renoise_blur_2_noise_factor_curve_interval_shift", ParameterParserDataType::UInt32, (double)renoise_blur_2_noise_factor_curve_interval_shift, 0));
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_interval_shift") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)renoise_blur_2_noise_factor_curve_interval_shift, 0));
    }

    // use_map_from_lower_pass
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("use_map_from_lower_pass", ParameterParserDataType::UInt32, (double)use_map_from_lower_pass, 0));
    }
    else if (PARAMETER_STRCMP(__name, "use_map_from_lower_pass") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)use_map_from_lower_pass, 0));
    }

    return __result;
}

bool chromatix_blur10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_pass_reserve_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_reserve_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_blur10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_pass_reserve_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_reserve_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_blur10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_pass_reserve_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_pass_reserve_data", ParameterParserDataType::Structure, true, false, 4));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_pass_reserve_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_reserve_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, 4));
        }
    }

    return __result;
}

bool blur10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_luma_lut_tab") == 0)
    {
        __result = luma2noise_curve_luma_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma2noise_curve_chroma_lut_tab") == 0)
    {
        __result = luma2noise_curve_chroma_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_tab") == 0)
    {
        __result = renoise_blur_2_noise_factor_curve_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "below_focus_blur_rate") == 0)
    {
        ParameterUtils::DoubleToString((double)below_focus_blur_rate, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "above_focus_blur_rate") == 0)
    {
        ParameterUtils::DoubleToString((double)above_focus_blur_rate, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "renoise_strength") == 0)
    {
        ParameterUtils::DoubleToString((double)renoise_strength, __value, __size);
        __result = true;
    }

    return __result;
}

bool blur10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_luma_lut_tab") == 0)
    {
        __result = luma2noise_curve_luma_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma2noise_curve_chroma_lut_tab") == 0)
    {
        __result = luma2noise_curve_chroma_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_tab") == 0)
    {
        __result = renoise_blur_2_noise_factor_curve_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "below_focus_blur_rate") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            below_focus_blur_rate = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "above_focus_blur_rate") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            above_focus_blur_rate = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "renoise_strength") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            renoise_strength = (float)dblValue; 
        }
    }

    return __result;
}

bool blur10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma2noise_curve_luma_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma2noise_curve_luma_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma2noise_curve_luma_lut_tab") == 0)
    {
        __result = luma2noise_curve_luma_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // luma2noise_curve_chroma_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma2noise_curve_chroma_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma2noise_curve_chroma_lut_tab") == 0)
    {
        __result = luma2noise_curve_chroma_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // renoise_blur_2_noise_factor_curve_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("renoise_blur_2_noise_factor_curve_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve_tab") == 0)
    {
        __result = renoise_blur_2_noise_factor_curve_tab.GetInfo(&__path[__pos], __info);
    }

    // below_focus_blur_rate
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("below_focus_blur_rate", ParameterParserDataType::Float, (double)below_focus_blur_rate));
    }
    else if (PARAMETER_STRCMP(__name, "below_focus_blur_rate") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)below_focus_blur_rate));
    }

    // above_focus_blur_rate
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("above_focus_blur_rate", ParameterParserDataType::Float, (double)above_focus_blur_rate));
    }
    else if (PARAMETER_STRCMP(__name, "above_focus_blur_rate") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)above_focus_blur_rate));
    }

    // renoise_strength
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("renoise_strength", ParameterParserDataType::Float, (double)renoise_strength));
    }
    else if (PARAMETER_STRCMP(__name, "renoise_strength") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)renoise_strength));
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_luma_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_luma_lut") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)luma2noise_curve_luma_lut[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma2noise_curve_luma_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_luma_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_luma_lut") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma2noise_curve_luma_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma2noise_curve_luma_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_luma_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma2noise_curve_luma_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma2noise_curve_luma_lut", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_chroma_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_chroma_lut") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)luma2noise_curve_chroma_lut[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma2noise_curve_chroma_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_chroma_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma2noise_curve_chroma_lut") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma2noise_curve_chroma_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma2noise_curve_chroma_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::luma2noise_curve_chroma_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma2noise_curve_chroma_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma2noise_curve_chroma_lut", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool blur10_rgn_dataType::renoise_blur_2_noise_factor_curve_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve") == 0)
    {
        if (__index < 33)
        {
            ParameterUtils::DoubleToString((double)renoise_blur_2_noise_factor_curve[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 33; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)renoise_blur_2_noise_factor_curve[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::renoise_blur_2_noise_factor_curve_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "renoise_blur_2_noise_factor_curve") == 0)
    {
        if (__index < 33)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                renoise_blur_2_noise_factor_curve[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 33)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    renoise_blur_2_noise_factor_curve[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool blur10_rgn_dataType::renoise_blur_2_noise_factor_curve_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // renoise_blur_2_noise_factor_curve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("renoise_blur_2_noise_factor_curve", ParameterParserDataType::UInt32, true, false, 33));
    }

    return __result;
}

bool mod_blur10_pass_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)pass_trigger, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "blur10_rgn_data") == 0)
    {
        __result = blur10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_pass_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            pass_trigger = (ispglobalelements::trigger_pass)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "blur10_rgn_data") == 0)
    {
        __result = blur10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_pass_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // pass_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pass_trigger", ParameterParserDataType::Enum, (double)(UINT32)pass_trigger, 0));
    }
    else if (PARAMETER_STRCMP(__name, "pass_trigger") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)pass_trigger, 0));
    }

    // blur10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blur10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "blur10_rgn_data") == 0)
    {
        __result = blur10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_cct_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "cct_data") == 0)
    {
        __result = cct_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_cct_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "cct_data") == 0)
    {
        __result = cct_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_cct_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // cct_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cct_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetInfo(&__path[__pos], __info);
    }

    // cct_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cct_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "cct_data") == 0)
    {
        __result = cct_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_cct_dataType::cct_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_pass_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_blur10_cct_dataType::cct_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_pass_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_blur10_cct_dataType::cct_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_pass_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_pass_data", ParameterParserDataType::Structure, true, false, 4));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_pass_data") == 0)
    {
        if (__index < 4)
        {
            __result = mod_blur10_pass_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, 4));
        }
    }

    return __result;
}

bool mod_blur10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_aec_dataType::aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_cct_data") == 0)
    {
        if (__index < mod_blur10_cct_dataCount)
        {
            __result = mod_blur10_cct_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_blur10_aec_dataType::aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_cct_data") == 0)
    {
        if (__index < mod_blur10_cct_dataCount)
        {
            __result = mod_blur10_cct_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_blur10_aec_dataType::aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_cct_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_cct_data", ParameterParserDataType::Structure, true, false, mod_blur10_cct_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_cct_data") == 0)
    {
        if (__index < mod_blur10_cct_dataCount)
        {
            __result = mod_blur10_cct_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_blur10_cct_dataCount));
        }
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_aec_data") == 0)
    {
        if (__index < mod_blur10_aec_dataCount)
        {
            __result = mod_blur10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_aec_data") == 0)
    {
        if (__index < mod_blur10_aec_dataCount)
        {
            __result = mod_blur10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_blur10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_aec_data", ParameterParserDataType::Structure, true, false, mod_blur10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_aec_data") == 0)
    {
        if (__index < mod_blur10_aec_dataCount)
        {
            __result = mod_blur10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_blur10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_hdr_aec_data") == 0)
    {
        if (__index < mod_blur10_hdr_aec_dataCount)
        {
            __result = mod_blur10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_hdr_aec_data") == 0)
    {
        if (__index < mod_blur10_hdr_aec_dataCount)
        {
            __result = mod_blur10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_blur10_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_blur10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_hdr_aec_data") == 0)
    {
        if (__index < mod_blur10_hdr_aec_dataCount)
        {
            __result = mod_blur10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_blur10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_blur10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_drc_gain_data") == 0)
    {
        if (__index < mod_blur10_drc_gain_dataCount)
        {
            __result = mod_blur10_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_blur10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_blur10_drc_gain_data") == 0)
    {
        if (__index < mod_blur10_drc_gain_dataCount)
        {
            __result = mod_blur10_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_blur10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_blur10_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_blur10_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_blur10_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_blur10_drc_gain_data") == 0)
    {
        if (__index < mod_blur10_drc_gain_dataCount)
        {
            __result = mod_blur10_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_blur10_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_blur10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_reserve") == 0)
    {
        __result = chromatix_blur10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_core") == 0)
    {
        __result = chromatix_blur10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_blur10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_reserve") == 0)
    {
        __result = chromatix_blur10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_core") == 0)
    {
        __result = chromatix_blur10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_blur10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_blur10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_blur10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_reserve") == 0)
    {
        __result = chromatix_blur10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_blur10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_blur10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_blur10_core") == 0)
    {
        __result = chromatix_blur10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_blur10Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "renoise_en") == 0)
    {
        ParameterUtils::DoubleToString((double)renoise_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "en") == 0)
    {
        ParameterUtils::DoubleToString((double)en, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_blur10Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "renoise_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            renoise_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            en = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_blur10Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // renoise_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("renoise_en", ParameterParserDataType::Int32, (double)renoise_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "renoise_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)renoise_en, 0));
    }

    // en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("en", ParameterParserDataType::Int32, (double)en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)en, 0));
    }

    return __result;
}

bool chromatix_blur10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_blur10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_blur10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_blur10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_blur10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_blur10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_blur10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 5; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_blur10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 5)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_blur10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 5));
    }

    return __result;
}

bool chromatix_blur10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_blur10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_blur10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_blur10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_cct):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_cct;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_pass):
            enumValue = chromatix_blur10Type::control_variablesStruct::control_var_typeEnum::control_pass;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_blur10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_blur10TypeClass::chromatix_blur10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_blur10_reserve);
    PARAMETER_INITIALIZE(chromatix_blur10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_blur10TypeClass::chromatix_blur10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_blur10_reserve);
    PARAMETER_INITIALIZE(chromatix_blur10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_blur10TypeClass::~chromatix_blur10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_blur10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "blur10_ipe")) == 0)
    {
        name = "blur10_ipe";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_pass_reserve_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_pass_reserve_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(pass_trigger);
    PARAMETER_INITIALIZE(pass_data);

    result = ispglobalelements::ReadEnum_trigger_pass(entry, pass_trigger, alignment);
    if (result)
    {
        result = pass_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_pass_reserve_dataType_pass_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_pass_reserve_dataType::pass_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(map_lut_en);
    PARAMETER_INITIALIZE(jbu_en);
    PARAMETER_INITIALIZE(dc2_filter_coef_1_luma);
    PARAMETER_INITIALIZE(dc2_filter_coef_2_luma);
    PARAMETER_INITIALIZE(dc2_filter_coef_3_luma);
    PARAMETER_INITIALIZE(dc2_filter_coef_4_luma);
    PARAMETER_INITIALIZE(dc2_filter_coef_5_luma);
    PARAMETER_INITIALIZE(dc2_filter_coef_1_chroma);
    PARAMETER_INITIALIZE(dc2_filter_coef_2_chroma);
    PARAMETER_INITIALIZE(dc2_filter_coef_3_chroma);
    PARAMETER_INITIALIZE(dc2_filter_coef_4_chroma);
    PARAMETER_INITIALIZE(dc2_filter_coef_5_chroma);
    PARAMETER_INITIALIZE(renoise_blur_2_noise_factor_curve_interval_shift);
    PARAMETER_INITIALIZE(use_map_from_lower_pass);

    SYMBOL_TABLE_ENTRY_READ(entry, result, map_lut_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, jbu_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_1_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_2_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_3_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_4_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_5_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_1_chroma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_2_chroma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_3_chroma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_4_chroma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dc2_filter_coef_5_chroma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, renoise_blur_2_noise_factor_curve_interval_shift, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, use_map_from_lower_pass, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_blur10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_pass_reserve_data);

    for (UINT32 i = 0; result && i < 4; i++)
    {
        result = mod_blur10_pass_reserve_data[i].Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load blur10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool blur10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma2noise_curve_luma_lut_tab);
    PARAMETER_INITIALIZE(luma2noise_curve_chroma_lut_tab);
    PARAMETER_INITIALIZE(renoise_blur_2_noise_factor_curve_tab);
    PARAMETER_INITIALIZE(below_focus_blur_rate);
    PARAMETER_INITIALIZE(above_focus_blur_rate);
    PARAMETER_INITIALIZE(renoise_strength);

    result = luma2noise_curve_luma_lut_tab.Load(entry, alignment);
    if (result)
    {
        result = luma2noise_curve_chroma_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = renoise_blur_2_noise_factor_curve_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, below_focus_blur_rate, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, above_focus_blur_rate, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, renoise_strength, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load blur10_rgn_dataType_luma2noise_curve_luma_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool blur10_rgn_dataType::luma2noise_curve_luma_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma2noise_curve_luma_lut);

    result = entry->ReadArray(luma2noise_curve_luma_lut, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load blur10_rgn_dataType_luma2noise_curve_chroma_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool blur10_rgn_dataType::luma2noise_curve_chroma_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma2noise_curve_chroma_lut);

    result = entry->ReadArray(luma2noise_curve_chroma_lut, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load blur10_rgn_dataType_renoise_blur_2_noise_factor_curve_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool blur10_rgn_dataType::renoise_blur_2_noise_factor_curve_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(renoise_blur_2_noise_factor_curve);

    result = entry->ReadArray(renoise_blur_2_noise_factor_curve, 33, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_pass_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_pass_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(pass_trigger);
    PARAMETER_INITIALIZE(blur10_rgn_data);

    result = ispglobalelements::ReadEnum_trigger_pass(entry, pass_trigger, alignment);
    if (result)
    {
        result = blur10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_cct_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_cct_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(cct_trigger);
    PARAMETER_INITIALIZE(cct_data);

    result = cct_trigger.Load(entry, alignment);
    if (result)
    {
        result = cct_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_cct_dataType_cct_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_cct_dataType::cct_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_pass_data);

    for (UINT32 i = 0; result && i < 4; i++)
    {
        result = mod_blur10_pass_data[i].Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(aec_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_aec_dataType::aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_cct_data);


    // Reading Array mod_blur10_cct_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_blur10_cct_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_blur10_cct_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_blur10_cct_dataID = pointerEntry->ID;
            DupObjInfo* mod_blur10_cct_dataDupInfo = pointerEntry->GetDupObject(mod_blur10_cct_dataCount, file, line);
            if (mod_blur10_cct_dataDupInfo != nullptr && mod_blur10_cct_dataDupInfo->Object != nullptr)
            {
                mod_blur10_cct_data = (mod_blur10_cct_dataType*)mod_blur10_cct_dataDupInfo->Object;
                if (mod_blur10_cct_data == nullptr)
                {
                    if (mod_blur10_cct_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_cct_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_blur10_cct_dataDupInfo->File, mod_blur10_cct_dataDupInfo->Line, mod_blur10_cct_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_cct_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_blur10_cct_dataDupInfo->Line, mod_blur10_cct_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_blur10_cct_data == nullptr)
            {
                if (result && mod_blur10_cct_dataCount > 0)
                {
                    mod_blur10_cct_data = PARAMETER_NEW mod_blur10_cct_dataType[mod_blur10_cct_dataCount];
                    (void)pointerEntry->SetDupObject(mod_blur10_cct_data, mod_blur10_cct_dataCount, file, line);
                }
                if (!result || mod_blur10_cct_data == nullptr)
                {
                    if (mod_blur10_cct_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_blur10_cct_data\n");
                    }
                    mod_blur10_cct_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_blur10_cct_dataCount; i++)
                {
                    result = mod_blur10_cct_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_blur10_cct_data == nullptr)
        {
            mod_blur10_cct_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_aec_data);


    // Reading Array mod_blur10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_blur10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_blur10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_blur10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_blur10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_blur10_aec_dataCount, file, line);
            if (mod_blur10_aec_dataDupInfo != nullptr && mod_blur10_aec_dataDupInfo->Object != nullptr)
            {
                mod_blur10_aec_data = (mod_blur10_aec_dataType*)mod_blur10_aec_dataDupInfo->Object;
                if (mod_blur10_aec_data == nullptr)
                {
                    if (mod_blur10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_blur10_aec_dataDupInfo->File, mod_blur10_aec_dataDupInfo->Line, mod_blur10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_blur10_aec_dataDupInfo->Line, mod_blur10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_blur10_aec_data == nullptr)
            {
                if (result && mod_blur10_aec_dataCount > 0)
                {
                    mod_blur10_aec_data = PARAMETER_NEW mod_blur10_aec_dataType[mod_blur10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_blur10_aec_data, mod_blur10_aec_dataCount, file, line);
                }
                if (!result || mod_blur10_aec_data == nullptr)
                {
                    if (mod_blur10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_blur10_aec_data\n");
                    }
                    mod_blur10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_blur10_aec_dataCount; i++)
                {
                    result = mod_blur10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_blur10_aec_data == nullptr)
        {
            mod_blur10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_blur10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_blur10_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_hdr_aec_data);


    // Reading Array mod_blur10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_blur10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_blur10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_blur10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_blur10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_blur10_hdr_aec_dataCount, file, line);
            if (mod_blur10_hdr_aec_dataDupInfo != nullptr && mod_blur10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_blur10_hdr_aec_data = (mod_blur10_hdr_aec_dataType*)mod_blur10_hdr_aec_dataDupInfo->Object;
                if (mod_blur10_hdr_aec_data == nullptr)
                {
                    if (mod_blur10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_blur10_hdr_aec_dataDupInfo->File, mod_blur10_hdr_aec_dataDupInfo->Line, mod_blur10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_blur10_hdr_aec_dataDupInfo->Line, mod_blur10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_blur10_hdr_aec_data == nullptr)
            {
                if (result && mod_blur10_hdr_aec_dataCount > 0)
                {
                    mod_blur10_hdr_aec_data = PARAMETER_NEW mod_blur10_hdr_aec_dataType[mod_blur10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_blur10_hdr_aec_data, mod_blur10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_blur10_hdr_aec_data == nullptr)
                {
                    if (mod_blur10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_blur10_hdr_aec_data\n");
                    }
                    mod_blur10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_blur10_hdr_aec_dataCount; i++)
                {
                    result = mod_blur10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_blur10_hdr_aec_data == nullptr)
        {
            mod_blur10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_blur10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_blur10_drc_gain_data);


    // Reading Array mod_blur10_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_blur10_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_blur10_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_blur10_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_blur10_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_blur10_drc_gain_dataCount, file, line);
            if (mod_blur10_drc_gain_dataDupInfo != nullptr && mod_blur10_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_blur10_drc_gain_data = (mod_blur10_drc_gain_dataType*)mod_blur10_drc_gain_dataDupInfo->Object;
                if (mod_blur10_drc_gain_data == nullptr)
                {
                    if (mod_blur10_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_blur10_drc_gain_dataDupInfo->File, mod_blur10_drc_gain_dataDupInfo->Line, mod_blur10_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_blur10_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_blur10_drc_gain_dataDupInfo->Line, mod_blur10_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_blur10_drc_gain_data == nullptr)
            {
                if (result && mod_blur10_drc_gain_dataCount > 0)
                {
                    mod_blur10_drc_gain_data = PARAMETER_NEW mod_blur10_drc_gain_dataType[mod_blur10_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_blur10_drc_gain_data, mod_blur10_drc_gain_dataCount, file, line);
                }
                if (!result || mod_blur10_drc_gain_data == nullptr)
                {
                    if (mod_blur10_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_blur10_drc_gain_data\n");
                    }
                    mod_blur10_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_blur10_drc_gain_dataCount; i++)
                {
                    result = mod_blur10_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_blur10_drc_gain_data == nullptr)
        {
            mod_blur10_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_blur10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_blur10_reserve);
    PARAMETER_INITIALIZE(chromatix_blur10_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_blur10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_blur10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(renoise_en);
    PARAMETER_INITIALIZE(en);

    SYMBOL_TABLE_ENTRY_READ(entry, result, renoise_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, en, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 5; i++)
    {
        result = chromatix_blur10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_aec_dataType::aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_blur10_cct_data))
    {
        PARAMETER_DELETE[] mod_blur10_cct_data;
    }
    mod_blur10_cct_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_blur10_aec_dataCount; i++)
    {
        mod_blur10_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_blur10_aec_data))
    {
        PARAMETER_DELETE[] mod_blur10_aec_data;
    }
    mod_blur10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_blur10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_blur10_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_blur10_hdr_aec_dataCount; i++)
    {
        mod_blur10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_blur10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_blur10_hdr_aec_data;
    }
    mod_blur10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_blur10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_blur10_drc_gain_dataCount; i++)
    {
        mod_blur10_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_blur10_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_blur10_drc_gain_data;
    }
    mod_blur10_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_blur10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_blur10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10Type::Release()
{
    ((chromatix_blur10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_blur10Type::GetModified()
{
    return ((chromatix_blur10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_blur10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_blur10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_blur10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_blur10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_blur10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_blur10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_blur10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_blur10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_blur10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_blur10TypeClass::Release()
{
    ParameterModule::Release();
}

BLUR_1_0_0_NAMESPACE_END
